@@ -54,6 +54,7 @@ class PlexObject(object):
             self._loadData(data)
         self._details_key = self._buildDetailsKey()
         self._autoReload = False
+        self._edits = None  # Save batch edits for a single API call
 
     def __repr__(self):
         uid = self._clean(self.firstAttr('_baseurl', 'key', 'id', 'playQueueID', 'uri'))
@@ -169,9 +170,14 @@ class PlexObject(object):
             raise BadRequest('ekey was not provided')
         if isinstance(ekey, int):
             ekey = '/library/metadata/%s' % ekey
-        for elem in self._server.query(ekey):
+        data = self._server.query(ekey)
+        librarySectionID = utils.cast(int, data.attrib.get('librarySectionID'))
+        for elem in data:
             if self._checkAttrs(elem, **kwargs):
-                return self._buildItem(elem, cls, ekey)
+                item = self._buildItem(elem, cls, ekey)
+                if librarySectionID:
+                    item.librarySectionID = librarySectionID
+                return item
         clsname = cls.__name__ if cls else 'None'
         raise NotFound('Unable to find elem: cls=%s, attrs=%s' % (clsname, kwargs))
 
@@ -196,7 +202,7 @@ class PlexObject(object):
             Any XML attribute can be filtered when fetching results. Filtering is done before
             the Python objects are built to help keep things speedy. For example, passing in
             ``viewCount=0`` will only return matching items where the view count is ``0``.
-            Note that case matters when specifying attributes. Attributes futher down in the XML
+            Note that case matters when specifying attributes. Attributes further down in the XML
             tree can be filtered by *prepending* the attribute with each element tag ``Tag__``.
 
             Examples:
@@ -228,12 +234,12 @@ class PlexObject(object):
             * ``__exists`` (*bool*): Value is or is not present in the attrs.
             * ``__gt``: Value is greater than specified arg.
             * ``__gte``: Value is greater than or equal to specified arg.
-            * ``__icontains``: Case insensative value contains specified arg.
-            * ``__iendswith``: Case insensative value ends with specified arg.
-            * ``__iexact``: Case insensative value matches specified arg.
+            * ``__icontains``: Case insensitive value contains specified arg.
+            * ``__iendswith``: Case insensitive value ends with specified arg.
+            * ``__iexact``: Case insensitive value matches specified arg.
             * ``__in``: Value is in a specified list or tuple.
-            * ``__iregex``: Case insensative value matches the specified regular expression.
-            * ``__istartswith``: Case insensative value starts with specified arg.
+            * ``__iregex``: Case insensitive value matches the specified regular expression.
+            * ``__istartswith``: Case insensitive value starts with specified arg.
             * ``__lt``: Value is less than specified arg.
             * ``__lte``: Value is less than or equal to specified arg.
             * ``__regex``: Value matches the specified regular expression.
@@ -392,7 +398,7 @@ class PlexObject(object):
         # check were looking for the tag
         if attr.lower() == 'etag':
             return [elem.tag]
-        # loop through attrs so we can perform case-insensative match
+        # loop through attrs so we can perform case-insensitive match
         for _attr, value in elem.attrib.items():
             if attr.lower() == _attr.lower():
                 return [value]
@@ -414,6 +420,10 @@ class PlexObject(object):
     def _loadData(self, data):
         raise NotImplementedError('Abstract method not implemented.')
 
+    @property
+    def _searchType(self):
+        return self.TYPE
+
 
 class PlexPartialObject(PlexObject):
     """ Not all objects in the Plex listings return the complete list of elements
@@ -455,7 +465,7 @@ class PlexPartialObject(PlexObject):
     def __getattribute__(self, attr):
         # Dragons inside.. :-/
         value = super(PlexPartialObject, self).__getattribute__(attr)
-        # Check a few cases where we dont want to reload
+        # Check a few cases where we don't want to reload
         if attr in _DONT_RELOAD_FOR_KEYS: return value
         if attr in _DONT_OVERWRITE_SESSION_KEYS: return value
         if attr in USER_DONT_RELOAD_FOR_KEYS: return value
@@ -507,44 +517,79 @@ class PlexPartialObject(PlexObject):
 
     def _edit(self, **kwargs):
         """ Actually edit an object. """
+        if isinstance(self._edits, dict):
+            self._edits.update(kwargs)
+            return self
+
         if 'id' not in kwargs:
             kwargs['id'] = self.ratingKey
         if 'type' not in kwargs:
-            kwargs['type'] = utils.searchType(self.type)
+            kwargs['type'] = utils.searchType(self._searchType)
 
-        part = '/library/sections/%s/all?%s' % (self.librarySectionID,
-                                                urlencode(kwargs))
+        part = '/library/sections/%s/all%s' % (self.librarySectionID,
+                                               utils.joinArgs(kwargs))
         self._server.query(part, method=self._server._session.put)
+        return self
 
     def edit(self, **kwargs):
         """ Edit an object.
+            Note: This is a low level method and you need to know all the field/tag keys.
+            See :class:`~plexapi.mixins.EditFieldMixin` and :class:`~plexapi.mixins.EditTagsMixin`
+            for individual field and tag editing methods.
 
             Parameters:
                 kwargs (dict): Dict of settings to edit.
 
             Example:
-                {'type': 1,
-                 'id': movie.ratingKey,
-                 'collection[0].tag.tag': 'Super',
-                 'collection.locked': 0}
-        """
-        self._edit(**kwargs)
 
-    def _edit_tags(self, tag, items, locked=True, remove=False):
-        """ Helper to edit tags.
+                .. code-block:: python
+
+                    edits = {
+                        'type': 1,
+                        'id': movie.ratingKey,
+                        'title.value': 'A new title',
+                        'title.locked': 1,
+                        'summary.value': 'This is a summary.',
+                        'summary.locked': 1,
+                        'collection[0].tag.tag': 'A tag',
+                        'collection.locked': 1}
+                    }
+                    movie.edit(**edits)
 
-            Parameters:
-                tag (str): Tag name.
-                items (list): List of tags to add.
-                locked (bool): True to lock the field.
-                remove (bool): True to remove the tags in items.
         """
-        if not isinstance(items, list):
-            items = [items]
-        value = getattr(self, utils.tag_plural(tag))
-        existing_tags = [t.tag for t in value if t and remove is False]
-        tag_edits = utils.tag_helper(tag, existing_tags + items, locked, remove)
-        self.edit(**tag_edits)
+        return self._edit(**kwargs)
+
+    def batchEdits(self):
+        """ Enable batch editing mode to save API calls.
+            Must call :func:`~plexapi.base.PlexPartialObject.saveEdits` at the end to save all the edits.
+            See :class:`~plexapi.mixins.EditFieldMixin` and :class:`~plexapi.mixins.EditTagsMixin`
+            for individual field and tag editing methods.
+
+            Example:
+
+                .. code-block:: python
+
+                    # Batch editing multiple fields and tags in a single API call
+                    Movie.batchEdits()
+                    Movie.editTitle('A New Title').editSummary('A new summary').editTagline('A new tagline') \\
+                        .addCollection('New Collection').removeGenre('Action').addLabel('Favorite')
+                    Movie.saveEdits()
+
+        """
+        self._edits = {}
+        return self
+
+    def saveEdits(self):
+        """ Save all the batch edits and automatically reload the object.
+            See :func:`~plexapi.base.PlexPartialObject.batchEdits` for details.
+        """
+        if not isinstance(self._edits, dict):
+            raise BadRequest('Batch editing mode not enabled. Must call `batchEdits()` first.')
+
+        edits = self._edits
+        self._edits = None
+        self._edit(**edits)
+        return self.reload()
 
     def refresh(self):
         """ Refreshing a Library or individual item causes the metadata for the item to be
@@ -709,7 +754,7 @@ class Playable(object):
                 filename = part.file
 
             if kwargs:
-                # So this seems to be a alot slower but allows transcode.
+                # So this seems to be a a lot slower but allows transcode.
                 download_url = self.getStreamURL(**kwargs)
             else:
                 download_url = self._server.url('%s?download=1' % part.key)
