@@ -5,11 +5,21 @@ from urllib.parse import quote_plus
 from plexapi import media, utils, video
 from plexapi.base import Playable, PlexPartialObject
 from plexapi.exceptions import BadRequest
-from plexapi.mixins import ArtUrlMixin, ArtMixin, PosterUrlMixin, PosterMixin, RatingMixin, TagMixin
+from plexapi.mixins import (
+    RatingMixin,
+    ArtUrlMixin, ArtMixin, PosterUrlMixin, PosterMixin,
+    SortTitleMixin, SummaryMixin, TitleMixin, PhotoCapturedTimeMixin,
+    TagMixin
+)
 
 
 @utils.registerPlexObject
-class Photoalbum(PlexPartialObject, ArtMixin, PosterMixin, RatingMixin):
+class Photoalbum(
+    PlexPartialObject,
+    RatingMixin,
+    ArtMixin, PosterMixin,
+    SortTitleMixin, SummaryMixin, TitleMixin
+):
     """ Represents a single Photoalbum (collection of photos).
 
         Attributes:
@@ -33,11 +43,12 @@ class Photoalbum(PlexPartialObject, ArtMixin, PosterMixin, RatingMixin):
             title (str): Name of the photo album. (Trip to Disney World)
             titleSort (str): Title to use when sorting (defaults to title).
             type (str): 'photo'
-            updatedAt (datatime): Datetime the photo album was updated.
+            updatedAt (datetime): Datetime the photo album was updated.
             userRating (float): Rating of the photo album (0.0 - 10.0) equaling (0 stars - 5 stars).
     """
     TAG = 'Directory'
     TYPE = 'photo'
+    _searchType = 'photoalbum'
 
     def _loadData(self, data):
         """ Load attribute values from Plex XML response. """
@@ -109,7 +120,7 @@ class Photoalbum(PlexPartialObject, ArtMixin, PosterMixin, RatingMixin):
         return self.episode(title)
 
     def download(self, savepath=None, keep_original_name=False, subfolders=False):
-        """ Download all photos and clips from the photo ablum. See :func:`~plexapi.base.Playable.download` for details.
+        """ Download all photos and clips from the photo album. See :func:`~plexapi.base.Playable.download` for details.
 
             Parameters:
                 savepath (str): Defaults to current working dir.
@@ -131,7 +142,13 @@ class Photoalbum(PlexPartialObject, ArtMixin, PosterMixin, RatingMixin):
 
 
 @utils.registerPlexObject
-class Photo(PlexPartialObject, Playable, ArtUrlMixin, PosterUrlMixin, RatingMixin, TagMixin):
+class Photo(
+    PlexPartialObject, Playable,
+    RatingMixin,
+    ArtUrlMixin, PosterUrlMixin,
+    PhotoCapturedTimeMixin, SortTitleMixin, SummaryMixin, TitleMixin,
+    TagMixin
+):
     """ Represents a single Photo.
 
         Attributes:
@@ -164,7 +181,7 @@ class Photo(PlexPartialObject, Playable, ArtUrlMixin, PosterUrlMixin, RatingMixi
             title (str): Name of the photo.
             titleSort (str): Title to use when sorting (defaults to title).
             type (str): 'photo'
-            updatedAt (datatime): Datetime the photo was updated.
+            updatedAt (datetime): Datetime the photo was updated.
             userRating (float): Rating of the photo (0.0 - 10.0) equaling (0 stars - 5 stars).
             year (int): Year the photo was taken.
     """
@@ -223,7 +240,7 @@ class Photo(PlexPartialObject, Playable, ArtUrlMixin, PosterUrlMixin, RatingMixi
         elif self.parentKey:
             return self._server.library.sectionByID(self.photoalbum().librarySectionID)
         else:
-            raise BadRequest('Unable to get section for photo, can`t find librarySectionID')
+            raise BadRequest("Unable to get section for photo, can't find librarySectionID")
 
     @property
     def locations(self):
