@@ -55,7 +55,7 @@ class SecretsFilter(logging.Filter):
 
 def registerPlexObject(cls):
     """ Registry of library types we may come across when parsing XML. This allows us to
-        define a few helper functions to dynamically convery the XML into objects. See
+        define a few helper functions to dynamically convert the XML into objects. See
         buildItem() below for an example.
     """
     etype = getattr(cls, 'STREAMTYPE', getattr(cls, 'TAGTYPE', cls.TYPE))
@@ -72,7 +72,7 @@ def cast(func, value):
         only support str, int, float, bool. Should be extended if needed.
 
         Parameters:
-            func (func): Calback function to used cast to type (int, bool, float).
+            func (func): Callback function to used cast to type (int, bool, float).
             value (any): value to be cast and returned.
     """
     if value is not None:
@@ -114,7 +114,7 @@ def lowerFirst(s):
 
 
 def rget(obj, attrstr, default=None, delim='.'):  # pragma: no cover
-    """ Returns the value at the specified attrstr location within a nexted tree of
+    """ Returns the value at the specified attrstr location within a nested tree of
         dicts, lists, tuples, functions, classes, etc. The lookup is done recursively
         for each key in attrstr (split by by the delimiter) This function is heavily
         influenced by the lookups used in Django templates.
@@ -361,40 +361,6 @@ def download(url, token, filename=None, savepath=None, session=None, chunksize=4
     return fullpath
 
 
-def tag_singular(tag):
-    if tag == 'countries':
-        return 'country'
-    elif tag == 'similar':
-        return 'similar'
-    else:
-        return tag[:-1]
-
-
-def tag_plural(tag):
-    if tag == 'country':
-        return 'countries'
-    elif tag == 'similar':
-        return 'similar'
-    else:
-        return tag + 's'
-
-
-def tag_helper(tag, items, locked=True, remove=False):
-    """ Simple tag helper for editing a object. """
-    if not isinstance(items, list):
-        items = [items]
-    data = {}
-    if not remove:
-        for i, item in enumerate(items):
-            tagname = '%s[%s].tag.tag' % (tag, i)
-            data[tagname] = item
-    if remove:
-        tagname = '%s[].tag.tag-' % tag
-        data[tagname] = ','.join(items)
-    data['%s.locked' % tag] = 1 if locked else 0
-    return data
-
-
 def getMyPlexAccount(opts=None):  # pragma: no cover
     """ Helper function tries to get a MyPlex Account instance by checking
         the the following locations for a username and password. This is
@@ -485,7 +451,7 @@ def getAgentIdentifier(section, agent):
         if agent in identifiers:
             return ag.identifier
         agents += identifiers
-    raise NotFound('Couldnt find "%s" in agents list (%s)' %
+    raise NotFound('Could not find "%s" in agents list (%s)' %
                    (agent, ', '.join(agents)))
 
 
